pub fn decide(outcome: TestOutcome) -> TestDecisionExpand description
Decide whether a test outcome passes or fails under the active policy.
pub fn decide(outcome: TestOutcome) -> TestDecisionDecide whether a test outcome passes or fails under the active policy.